<?php
/**
 * @package WordPress
 * @subpackage bodega Theme
*/


// Set the content width based on the theme's design and stylesheet.
if ( ! isset( $content_width ) ) 
    $content_width = 620;



/*-----------------------------------------------------------------------------------*/
/*	Include functions
/*-----------------------------------------------------------------------------------*/
require(get_template_directory() .'/admin/theme-admin.php');
require(get_template_directory() .'/functions/pagination.php');
require(get_template_directory() .'/functions/better-excerpts.php');
require(get_template_directory() .'/functions/shortcodes.php');
require(get_template_directory() .'/functions/meta/meta-box-class.php');
require(get_template_directory() .'/functions/meta/meta-box-usage.php');
require(get_template_directory() .'/functions/flickr-widget.php');



/*-----------------------------------------------------------------------------------*/
/*	Images
/*-----------------------------------------------------------------------------------*/
if ( function_exists( 'add_theme_support' ) )
	add_theme_support( 'post-thumbnails' );

if ( function_exists( 'add_image_size' ) ) {
	add_image_size( 'full-size',  9999, 9999, false );
	add_image_size( 'small-thumb',  50, 50, true );
	add_image_size( 'nivo-slider',  970, 360, true );
	add_image_size( 'post-image',  660, 220, true );
	add_image_size( 'portfolio-thumb',  215, 140, true );
	add_image_size( 'portfolio-single',  500, 9999, false );
}



/*-----------------------------------------------------------------------------------*/
/*	Javascsript
/*-----------------------------------------------------------------------------------*/

add_action('wp_enqueue_scripts','wpex_theme_scripts_function');
function wpex_theme_scripts_function() {
	
	//CSS
	wp_enqueue_style('prettyPhoto', get_template_directory_uri() .'/css/prettyPhoto.css');
	wp_enqueue_style('bodega-g-font', 'http://fonts.googleapis.com/css?family=bodega+Serif:400,400italic,700italic');
	
	// Load JQuery
	wp_enqueue_script('jquery');
	
	// Site wide js
	wp_enqueue_script('hoverIntent', get_template_directory_uri() . '/js/jquery.hoverIntent.minified.js', array('jquery'), '', true);
	wp_enqueue_script('superfish', get_template_directory_uri() . '/js/superfish.js', array('jquery'), '', true);
	wp_enqueue_script('nivo', get_template_directory_uri() . '/js/jquery.nivo.slider.js', array('jquery'), '', true);
	wp_enqueue_script('prettyphoto', get_template_directory_uri() . '/js/jquery.prettyPhoto.js', array('jquery'), '', true);
	wp_enqueue_script('custom', get_template_directory_uri() . '/js/custom.js', array('jquery'), '', true);

	//portfolio main
	if(is_page_template('template-portfolio.php')) {
		wp_enqueue_script('easing', get_template_directory_uri() . '/js/jquery.easing.1.3.js', array('jquery'), '', true);
		wp_enqueue_script('quicksand', get_template_directory_uri() . '/js/jquery.quicksand.js', array('jquery'), '', true);
		wp_enqueue_script('quicksandinit', get_template_directory_uri() . '/js/jquery.quicksandinit.js', array('jquery'), '', true);
	}
}



/*-----------------------------------------------------------------------------------*/
/*	Sidebars
/*-----------------------------------------------------------------------------------*/

//Register Sidebars
if ( function_exists('register_sidebar') )
	register_sidebar(array(
		'name' => 'Sidebar',
		'id' => 'sidebar',
		'description' => 'Widgets in this area will be shown in the sidebar.',
		'before_widget' => '<div class="sidebar-box clearfix">',
		'after_widget' => '</div>',
		'before_title' => '<h4><span>',
		'after_title' => '</span></h4>',
));
if ( function_exists('register_sidebar') )
	register_sidebar(array(
		'name' => 'Footer Left',
		'id' => 'footer-left',
		'description' => 'Widgets in this area will be shown in the footer left area.',
		'before_widget' => '<div class="footer-widget clearfix">',
		'after_widget' => '</div>',
		'before_title' => '<h4>',
		'after_title' => '</h4>',
));
if ( function_exists('register_sidebar') )
	register_sidebar(array(
		'name' => 'Footer Middle',
		'id' => 'footer-middle',
		'description' => 'Widgets in this area will be shown in the footer middle area.',
		'before_widget' => '<div class="footer-widget clearfix">',
		'after_widget' => '</div>',
		'before_title' => '<h4>',
		'after_title' => '</h4>',
));
if ( function_exists('register_sidebar') )
	register_sidebar(array(
		'name' => 'Footer Right',
		'id' => 'footer-right',
		'description' => 'Widgets in this area will be shown in the footer right area.',
		'before_widget' => '<div class="footer-widget clearfix">',
		'after_widget' => '</div>',
		'before_title' => '<h4>',
		'after_title' => '</h4>',
));



/*-----------------------------------------------------------------------------------*/
/*	Custom Post Types & Taxonomies
/*-----------------------------------------------------------------------------------*/

add_action( 'init', 'wpex_create_post_types' );
function wpex_create_post_types() {
	//slider post type
	register_post_type( 'Slides',
		array(
		  'labels' => array(
			'name' => __( 'HP Slides', 'bodega' ),
			'singular_name' => __( 'Slide', 'bodega' ),		
			'add_new' => _x( 'Add New', 'Slide', 'bodega' ),
			'add_new_item' => __( 'Add New Slide', 'bodega' ),
			'edit_item' => __( 'Edit Slide', 'bodega' ),
			'new_item' => __( 'New Slide', 'bodega' ),
			'view_item' => __( 'View Slide', 'bodega' ),
			'search_items' => __( 'Search Slides', 'bodega' ),
			'not_found' =>  __( 'No Slides found', 'bodega' ),
			'not_found_in_trash' => __( 'No Slides found in Trash', 'bodega' ),
			'parent_item_colon' => ''
			
		  ),
		  'public' => true,
		  'supports' => array('title','thumbnail'),
		  'query_var' => true,
		  'rewrite' => array( 'slug' => 'slides' ),
		)
	  );
	  
	//hp highlights
	register_post_type( 'hp_highlights',
		array(
		  'labels' => array(
			'name' => __( 'HP Highlights', 'bodega' ),
			'singular_name' => __( 'Highlight', 'bodega' ),		
			'add_new' => _x( 'Add New', 'Highlight', 'bodega' ),
			'add_new_item' => __( 'Add New Highlight', 'bodega' ),
			'edit_item' => __( 'Edit Highlight', 'bodega' ),
			'new_item' => __( 'New Highlight', 'bodega' ),
			'view_item' => __( 'View Highlight', 'bodega' ),
			'search_items' => __( 'Search Highlights', 'bodega' ),
			'not_found' =>  __( 'No Highlights found', 'bodega' ),
			'not_found_in_trash' => __( 'No Highlights found in Trash', 'bodega' ),
			'parent_item_colon' => ''
			
		  ),
		  'public' => true,
		  'supports' => array('title','editor'),
		  'query_var' => true,
		  'rewrite' => array( 'slug' => 'hp-highlights' ),
		)
	  );

	//portfolio post type
	register_post_type( 'Portfolio',
		array(
		  'labels' => array(
			'name' => __( 'Portfolio', 'bodega' ),
			'singular_name' => __( 'Portfolio', 'bodega' ),		
			'add_new' => _x( 'Add New', 'Portfolio Project', 'bodega' ),
			'add_new_item' => __( 'Add New Portfolio Project', 'bodega' ),
			'edit_item' => __( 'Edit Portfolio Project', 'bodega' ),
			'new_item' => __( 'New Portfolio Project', 'bodega' ),
			'view_item' => __( 'View Portfolio Project', 'bodega' ),
			'search_items' => __( 'Search Portfolio Projects', 'bodega' ),
			'not_found' =>  __( 'No Portfolio Projects found', 'bodega' ),
			'not_found_in_trash' => __( 'No Portfolio Projects found in Trash', 'bodega' ),
			'parent_item_colon' => ''
			
		  ),
		  'public' => true,
		  'supports' => array('title','editor','thumbnail'),
		  'query_var' => true,
		  'rewrite' => array( 'slug' => 'portfolio' ),
		)
	  );
}


// Add taxonomies
add_action( 'init', 'wpex_create_taxonomies' );

//create taxonomies
function wpex_create_taxonomies() {
	
// portfolio taxonomies
	$cat_labels = array(
		'name' => __( 'Portfolio Categories', 'bodega' ),
		'singular_name' => __( 'Portfolio Category', 'bodega' ),
		'search_items' =>  __( 'Search Portfolio Categories', 'bodega' ),
		'all_items' => __( 'All Portfolio Categories', 'bodega' ),
		'parent_item' => __( 'Parent Portfolio Category', 'bodega' ),
		'parent_item_colon' => __( 'Parent Portfolio Category:', 'bodega' ),
		'edit_item' => __( 'Edit Portfolio Category', 'bodega' ),
		'update_item' => __( 'Update Portfolio Category', 'bodega' ),
		'add_new_item' => __( 'Add New Portfolio Category', 'bodega' ),
		'new_item_name' => __( 'New Portfolio Category Name', 'bodega' ),
		'choose_from_most_used'	=> __( 'Choose from the most used portfolio categories', 'bodega' )
	); 	

	register_taxonomy('portfolio_cats','portfolio',array(
		'hierarchical' => false,
		'labels' => $cat_labels,
		'query_var' => true,
		'rewrite' => array( 'slug' => 'portfolio-category' ),
	));
}


/*-----------------------------------------------------------------------------------*/
/*	Portfolio Cat Pagination
/*-----------------------------------------------------------------------------------*/

// Set number of posts per page for taxonomy pages
$option_posts_per_page = get_option( 'posts_per_page' );
add_action( 'init', 'my_modify_posts_per_page', 0);
function my_modify_posts_per_page() {
    add_filter( 'option_posts_per_page', 'my_option_posts_per_page' );
}
function my_option_posts_per_page( $value ) {
	global $option_posts_per_page;
	
    if ( is_tax( 'portfolio_cats') ) {
        return 12;
    }
	else {
        return $option_posts_per_page;
    }
}

/*-----------------------------------------------------------------------------------*/
/*	Other functions
/*-----------------------------------------------------------------------------------*/

// Limit Post Word Count
function wpex_new_excerpt_length($length) {
	return 50;
}
add_filter('excerpt_length', 'wpex_new_excerpt_length');

//Replace Excerpt Link
function wpex_new_excerpt_more($more) {
       global $post;
	return '...';
}
add_filter('excerpt_more', 'wpex_new_excerpt_more');

// Enable Custom Background
add_theme_support( 'custom-background' );

// register navigation menus
register_nav_menus(
	array(
	'menu'=>__('Menu'),
	)
);

/// add home link to menu
function home_page_menu_args( $args ) {
$args['show_home'] = true;
return $args;
}
add_filter( 'wp_page_menu_args', 'home_page_menu_args' );

// menu fallback
function default_menu() {
	require_once (TEMPLATEPATH . '/includes/default-menu.php');
}


// Localization Support
load_theme_textdomain( 'bodega', TEMPLATEPATH.'/lang' );

//create featured image column
add_filter('manage_posts_columns', 'posts_columns', 5);
add_action('manage_posts_custom_column', 'posts_custom_columns', 5, 2);
function posts_columns($defaults){
    $defaults['riv_post_thumbs'] = __('Thumbs', 'powered');
    return $defaults;
}
function posts_custom_columns($column_name, $id){
	if($column_name === 'riv_post_thumbs'){
        echo the_post_thumbnail( 'small-thumb' );
    }
}

// functions run on activation --> important flush to clear rewrites
if ( is_admin() && isset($_GET['activated'] ) && $pagenow == 'themes.php' ) {
	$wp_rewrite->flush_rules();
}
?>